@@ -6,6 +6,7 @@ import os
 from sklearn.ensemble import BaggingClassifier
 import sys
 from importlib import import_module
+import shutil
 from sklearn.metrics import precision_score, recall_score
 from sklearn.metrics import confusion_matrix
 from sklearn.preprocessing import OrdinalEncoder
@@ -36,7 +37,7 @@ from sklearn.preprocessing import (OneHotEncoder,
 preprocess_vocab = {'one-hot', 'label-encode', 'fill', 'scale', 'dates', 'custom', 'min-max', 'ordinal', 'importance', 'clean-text', 'embed'}
 modeling_vocab = {'linear', 'svm', 'decision', 'sgd', 'neighbors', 'adaboost', 'gradient-boost', 'rf', 'svms', 'ensembles'}
 analysis_vocab = ['cross-val', 'acc-score', 'confusion', 'pr', 'importances', 'ALL']
-models = {"svm" : a_svm, "neighbors" : nearest_neighbors, "decision" : a_tree, "sgd" : sgd, "adaboost" : gradient_boosting, 'rf' : rf, 'mlp' : mlp, 'svms' : svm_stroke, 'ensembles' : ensemble_stroke }
+models = {"gradient-boost": gradient_boosting, "svm" : a_svm, "neighbors" : nearest_neighbors, "decision" : a_tree, "sgd" : sgd, "adaboost" : adaboost, 'rf' : rf, 'mlp' : mlp, 'svms' : svm_stroke, 'ensembles' : ensemble_stroke }
 just_models = {"svm", "neighbors", "decision", "sgd", "adaboost", "rf", "mlp"}
 
 def preprocess_module(request_info):
@@ -49,12 +50,22 @@ def preprocess_module(request_info):
             if element not in preprocess_vocab:
                 raise Exception("Your specificed preprocessing technique -- {} -- is not supported".format(element))
             if element == "custom":
-                mod = import_module(['preprocessor']['custom']['loc'])
 
+                sys_path = "/nylon/supplementaries/buffer/"
+                sys.path.insert(1, os.getcwd() + sys_path)
+
+                absolute_path = os.path.abspath(os.getcwd()) + '/nylon/supplementaries/buffer/temp.py'
+
+                file_name = json_file['preprocessor']['custom']['loc'].rsplit("/")[-1]
+                shutil.copy(json_file['preprocessor']['custom']['loc'], absolute_path)
+
+                mod = import_module('temp')
                 new_func = getattr(mod, json_file['preprocessor']['custom']['name'])
 
                 df = new_func(df, json_file)
-                os.remove(json_file['preprocessor']['custom']['loc'] + ".py")
+                sys.path.remove(sys_path)
+                os.remove("./buffer/temp.py")
+
             if element == "label-encode":
                 columns = preprocess['label-encode']
 
@@ -252,11 +263,21 @@ def modeling_module(request_info):
         model = default_modeling(df, y)
     else:
         if 'custom' in json_file['modeling']:
-            mod = import_module(['modeling']['custom']['loc'])
+
+            sys_path = "/nylon/supplementaries/buffer/"
+            sys.path.insert(1, os.getcwd() + sys_path)
+
+            absolute_path = os.path.abspath(os.getcwd()) + '/nylon/supplementaries/buffer/temp.py'
+            file_name = json_file['modeling']['custom']['loc'].rsplit("/")[-1]
+            shutil.copy(json_file['modeling']['custom']['loc'], absolute_path)
+
+            mod = import_module('temp')
             new_func = getattr(mod, json_file['modeling']['custom']['name'])
 
             model = new_func(df['train'], y['train'])
-            os.remove(json_file['modeling']['custom']['loc'] + ".py")
+            sys.path.remove(sys_path)
+            os.remove("./buffer/temp.py")
+
         if 'type' in json_file['modeling']:
             type_model = json_file['modeling']['type']
             model_storage = []
@@ -274,7 +295,7 @@ def modeling_module(request_info):
                         "The specified model -- {} -- is not in the list of available models".format(
                             a_model))
 
-                model = models[a_model](fifty_train, fifty_y)
+                model = models[a_model](fifty_train, fifty_y, json_file=json_file['modeling'])
                 model_storage.append(model)
 
                 curr_acc = accuracy_score(model.predict(df['test']), y['test'])
@@ -282,7 +303,7 @@ def modeling_module(request_info):
 
             max_accuracy = accs.index(max(accs))
             best_model_type = type_model[max_accuracy]
-            model = models[best_model_type](df['train'], y['train'])
+            model = models[best_model_type](df['train'], y['train'], json_file=json_file['modeling'])
         elif 'voting' in json_file['modeling']:
 
             classifiers = json_file['modeling']['voting']
@@ -319,7 +340,7 @@ def return_models_voting(classifier_list):
     estimators = []
 
     for classifier in classifier_list:
-        clf = models[classifier](None, None, trained=False)
+        clf = models[classifier](None, None, {"no_params": 0}, trained=False)
         estimators.append((str(clf), clf))
 
     return estimators
@@ -369,15 +390,24 @@ def analysis_module(request_info):
                         analysis_tuple['precision'] = precision
                         analysis_tuple['recall'] = recaller
             if element == "custom":
+                sys_path = "/nylon/supplementaries/buffer/"
+                sys.path.insert(1, os.getcwd() + sys_path)
 
-                mod = import_module(['analysis']['custom']['loc'])
-                new_func = getattr(mod, json_file['modeling']['custom']['name'])
+                absolute_path = os.path.abspath(os.getcwd()) + '/nylon/supplementaries/buffer/temp.py'
+
+                file_name = json_file['analysis']['custom']['loc'].rsplit("/")[-1]
+                shutil.copy(json_file['analysis']['custom']['loc'], absolute_path)
+
+                mod = import_module('temp')
+                new_func = getattr(mod, json_file['analysis']['custom']['name'])
 
                 results, name = new_func(json_file, df, model, y)
-                os.remove(json_file['analysis']['custom']['loc'] + ".py")
+                sys.path.remove(sys_path)
+                os.remove("./buffer/temp.py")
 
                 analysis_tuple[name] = results
 
+
     request_info['analysis'] = analysis_tuple
     return request_info
 
@@ -387,10 +417,6 @@ def default_analysis(json_file, model, df, y):
     matrix = confusion(model, df, y)
     precise = precision_calculation(model, df, y)
     recaller = recalll(model, df, y)
-
-    print("Results of accuracy score are -----  " + str(acc_results))
-    print("Results of CV are ------- " + str(cv_results))
-
     return acc_results, cv_results, matrix, precise, recaller
 
 
